Distortion — Map of Objects

Skip to main content
`Ctrl`+`K`

# Distortion

class TestDistortion(methodName='runTest')

calculate_distortion(experiment: Experiment, election_ids: List[str] | None = None, max_distance_percentage=1.0, normalize=True)
  Parameters:

    - normalize – whether to

    - max_distance_percentage

  :param experiment :param election_ids: list of elections to take into consideration. If none, takes all. :return: dict {election_id: mean distortion}